==> patch-2.5.3.18_3.zip: app/language/en/device.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'User',
	'profilePage' => 'User Account Details',
	'listOfUsers' => 'List of Users',
	'device' => 'Device',
	'devices' => 'Devices',
	'listOfDevices' => 'List of Devices',
	'policy_info' => 'Policy Information',
	'devicesBulkBlock' => 'Block Multiple Devices',
	'changeOwner' => 'Ownership changed for the selected device.',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'userSavedSuccess' => 'User Details updated successfully',
	'multipleDeviceBlocked' => 'The selected devices have been blocked successfully',
	'multipleDeviceUnBlocked' => 'The selected devices have been un-blocked successfully',
	'deviceBlocked' => 'The selected device has been blocked successfully',
	'deviceUnBlocked' => 'The selected device has been un-blocked successfully',
	'deviceLimitReached' => 'Device Limit exceeded. The device cannot be un-blocked.',
	'deviceLimitReachedDelete' => 'Device Limit exceeded.',
	'multipleDevicesDeleted' => 'The selected devices have been successfully deleted.',
	'deviceDeleted' => 'Selected device has been successfully deleted.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'447'       	=> 'Changes were not saved.  The selected user is under Legal hold.  Please contact your Administrator.',
	'417'       	=> '<b>User Limit exceeded</b>',
	'403'       	=> '<b>Backup User Limit exceeded</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>. Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>. Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'blockedDevices'   => 'Selected devices have been blocked successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.',
	'noDevices'   	=> 'There are no devices'
);

==> patch-2.5.5.3_1.zip: app/language/en/device.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'User',
	'profilePage' => 'User Account Details',
	'listOfUsers' => 'List of Users',
	'device' => 'Device',
	'devices' => 'Devices',
	'listOfDevices' => 'List of Devices',
	'policy_info' => 'Policy Information',
	'devicesBulkBlock' => 'Block Multiple Devices',
	'changeOwner' => 'Ownership changed for the selected device.',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'userSavedSuccess' => 'User Details updated successfully',
	'multipleDeviceBlocked' => 'The selected devices have been blocked successfully',
	'multipleDeviceUnBlocked' => 'The selected devices have been un-blocked successfully',
	'deviceBlocked' => 'The selected device has been blocked successfully',
	'deviceUnBlocked' => 'The selected device has been un-blocked successfully',
	'deviceLimitReached' => 'Device Limit exceeded. The device cannot be un-blocked.',
	'siteLimitReached' => 'Sites Limit reached',
	'deviceLimitReachedDelete' => 'Device Limit exceeded.',
	'multipleDevicesDeleted' => 'The selected devices have been successfully deleted.',
	'deviceDeleted' => 'Selected device has been successfully deleted.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'447'       	=> 'Changes were not saved.  The selected user is under Legal hold.  Please contact your Administrator.',
	'417'       	=> '<b>User Limit exceeded</b>',
	'1536'          => '<b>SharePoint Sites Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit exceeded</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>. Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>. Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'blockedDevices'   => 'Selected devices have been blocked successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.',
	'noDevices'   	=> 'There are no devices'
);
